A composite error type for errors that can occur while interacting with the server.
Structs
- Bravia
Error Code - Represents a specific error returned from a server API call.
Enums
- Error
- A set of errors that can occur when interacting with the server.
Type Aliases
- Result
- Alias to a Result containing a local Error type.